@@ -1,14 +1,14 @@
 from functools import partial
-from mapshader.utils import psutil_fetching, psutils_html
 import sys
 
+from bokeh.models.sources import GeoJSONDataSource
 from bokeh.plotting import figure
 from bokeh.models.tiles import WMTSTileSource
 from bokeh.embed import components
 from bokeh.tile_providers import STAMEN_TONER_BACKGROUND
 from bokeh.tile_providers import get_provider
 
-from jinja2 import Template
+from jinja2 import Environment, FileSystemLoader
 
 from bokeh.resources import INLINE
 
@@ -25,10 +25,13 @@ from mapshader.core import render_map
 from mapshader.core import render_geojson
 from mapshader.core import render_legend
 
-from mapshader.sources import get_services
-from mapshader.sources import MapSource
-from mapshader.sources import MapService
+from mapshader.services import get_services, MapService
 
+from mapshader.sources import MapSource
+
+from mapshader.utils import psutil_fetching
+
+jinja2_env = Environment(loader=FileSystemLoader("mapshader/templates/"))
 
 def flask_to_tile(source: MapSource, z=0, x=0, y=0):
 
@@ -107,7 +110,19 @@ def build_previewer(service: MapService):
     p.axis.visible = True
 
     if service.service_type == 'tile':
+        tile_source = WMTSTileSource(url=service.client_url,
+                                     min_zoom=0,
+                                     max_zoom=15)
 
+        p.add_tile(tile_source, render_parents=False)
+
+    elif service.service_type == 'geojson':
+        geo_source = GeoJSONDataSource(geojson=render_geojson(service.source))
+
+        p.patches('xs', 'ys', line_color='white', line_width=0.5, source=geo_source)
+
+    elif service.service_type == 'image':
+        # Bokeh ImageRGBA...?
         tile_source = WMTSTileSource(url=service.client_url,
                                      min_zoom=0,
                                      max_zoom=15)
@@ -121,116 +136,22 @@ def build_previewer(service: MapService):
 def service_page(service: MapService):
     plot = build_previewer(service)
     script, div = components(dict(preview=plot))
-
-    template = Template(
-        '''
-        <!DOCTYPE html>
-        <html lang="en">
-        <head>
-            <meta charset="utf-8">
-            <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Roboto">
-            <title>{{service.name}}</title>
-            {{ resources }}
-            {{ script }}
-            <style>
-                .embed-wrapper {
-                display: flex;
-                justify-content: space-evenly;
-                }
-                body {
-                font-family: "Roboto", sans-serif;
-                }
-                .header {
-                padding: 10px;
-                }
-            </style>
-        </head>
-        <body>
-            {{ psutils_html }}
-            <div class="header">
-                <h3>{{service.name}}</h3>
-                <hr />
-                <h5><strong>Client URL:</strong>
-                    {{service.client_url}}
-                </h5>
-                <h5><strong>Description:</strong>
-                    {{service.source.description}}
-                </h5>
-                <h5><strong>Geometry Type:</strong>
-                    {{service.source.geometry_type.capitalize()}}
-                </h5>
-            </div>
-            <hr />
-            <div class="embed-wrapper">
-                {% for key in div.keys() %}
-                {{ div[key] }}
-                {% endfor %}
-            </div>
-            <hr />
-            <div class="header">
-                <h4>Details</h4>
-                <hr />
-                <h5>
-                    <strong>
-                    Data Path:
-                    </strong>
-                    {{service.source.filepath}}
-                </h5>
-                <h5>
-                    <strong>
-                    Span:
-                    </strong>
-                    {{service.source.span}}
-                </h5>
-                <h5>
-                    <strong>
-                    Overviews:
-                    </strong>
-                    {{service.source.overviews.keys()}}
-                </h5>
-                <h5>
-                    <strong>
-                    Aggregation Method:
-                    </strong>
-                    {{service.source.agg_func}}
-                </h5>
-                <h5>
-                    <strong>
-                    Colormap Interpolation Method:
-                    </strong>
-                    {{service.source.shade_how}}
-                </h5>
-            </div>
-        </body>
-        </html>
-        '''
-    )
+    template = jinja2_env.get_template("service_page.html")
 
     resources = INLINE.render()
     html = template.render(resources=resources,
                            script=script,
                            service=service,
                            len=len,
-                           div=div,
-                           psutils_html=psutils_html())
+                           div=div)
 
     return html
 
 
 def index_page(services):
-    links = []
-    for s in services:
-        links.append(f'<li><a href="{s.service_page_url}">{s.name}</a></li>')
+    template = jinja2_env.get_template('index_page.html')
 
-    html = '<html>'
-    html += '<body>'
-    html += '<ul>'
-    html += ''.join(links)
-    html += '</ul>'
-    html += '</body>'
-    html += '</html>'
-
-    return html
+    return template.render(services=services)
 
 
 def configure_app(app: Flask, user_source_filepath=None, contains=None):
