@@ -8,6 +8,29 @@ import xarray as xr
 def load_raster(file_path, xmin=None, ymin=None,
                 xmax=None, ymax=None, chunks=None,
                 layername='data'):
+    """
+    Load raster data.
+
+    Parameters
+    ----------
+    file_path : str
+        Relative path to the file.
+    xmin : float
+        X-axis minimum range.
+    ymin : float
+        Y-axis minimum range.
+    xmax : float
+        X-axis maximum range.
+    ymax : float
+        Y-axis maximum range.
+    layername : str, default=data
+        Data layer name.
+
+    Returns
+    -------
+    arr : xarray.DataArray
+        The loaded data.
+    """
 
     if file_path.endswith('.tif'):
 
@@ -36,4 +59,17 @@ def load_raster(file_path, xmin=None, ymin=None,
 
 
 def load_vector(filepath: str):
+    """
+    Load vector data.
+
+    Parameters
+    ----------
+    filepath : str
+        Relative path to the file.
+
+    Returns
+    -------
+    gpd : geopandas.DataFrame
+        The loaded data.
+    """
     return gpd.read_file(filepath)
